/* tkUnixinactive.c -- unix versions of inactive functions. */

#include <tk.h>
#include <tkInt.h>
#include <X11/extensions/scrnsaver.h>

/*
*----------------------------------------------------------------------
*
* Tk_GetUserInactiveTime --
*
*	Return the number of milliseconds the user was inactive.
*
* Results:
*	The number of milliseconds since the user's latest interaction
*	with the system on the given display, or -1 if the
*	XScreenSaver extension is not supported by the client
*	libraries or the X server implementation.
*
* Side effects:
*	None.
*----------------------------------------------------------------------
*/

long
Tk_GetUserInactiveTime(dpy)
    Display *dpy;	/* The display for which to query the inactive time */
{
    long inactivetime = -1;
    int event_base;
    int error_base;

    if (XScreenSaverQueryExtension(dpy, &event_base, &error_base)) {
	XScreenSaverInfo *info;
	info = XScreenSaverAllocInfo();
	XScreenSaverQueryInfo(dpy, DefaultRootWindow(dpy), info);
	inactivetime = info->idle;
	XFree(info);
    }
    return inactivetime;
}

/*
 *----------------------------------------------------------------------
 *
 * Tk_ResetUserInactiveTime --
 *
 *	Reset the user inactivity timer
 *
 * Results:
 *	none
 *
 * Side effects:
 *	The user inactivity timer of the underlaying windowing system
 *	is reset to zero.
 *
 *----------------------------------------------------------------------
 */

void
Tk_ResetUserInactiveTime(dpy)
    Display *dpy;
{
    XResetScreenSaver(dpy);
}
